%% load data
clear
cb_ipa = load( '..\methodcomparison\cb\ipa\methodcomparison_cb_ipa.mat' );
cb_rnd = load( '..\methodcomparison\cb\rnd\methodcomparison_cb_rnd.mat' );
ce_ipa = load( '..\methodcomparison\ce\ipa\methodcomparison_ce_ipa.mat' );
ce_rnd = load( '..\methodcomparison\ce\rnd\methodcomparison_ce_rnd.mat' );

idx_ipa = arrayfun( @(n) ~isempty(cb_ipa.pt_VV(n).pts), 1:numel(cb_ipa.pt_VV) );
idx_rnd = arrayfun( @(n) ~isempty(cb_rnd.pt_VV(n).pts), 1:numel(cb_rnd.pt_VV) );

pt_VV_ipa = cb_ipa.pt_VV(idx_ipa);
pt_VV_rnd = cb_rnd.pt_VV(idx_rnd);

dim_ipa = arrayfun( @(n) size(pt_VV_ipa(n).VV,1), 1:numel(pt_VV_ipa) );
dim_rnd = arrayfun( @(n) size(pt_VV_ipa(n).VV,1), 1:numel(pt_VV_rnd) );

nVV_ipa = arrayfun( @(n) size(pt_VV_ipa(n).VV,2), 1:numel(pt_VV_ipa) );
nVV_rnd = arrayfun( @(n) size(pt_VV_ipa(n).VV,2), 1:numel(pt_VV_rnd) );

len_ipa = arrayfun( @(n) size(pt_VV_ipa(n).pts,2), 1:numel(pt_VV_ipa) );
len_rnd = arrayfun( @(n) size(pt_VV_rnd(n).pts,2), 1:numel(pt_VV_rnd) );

L1_ipa = @(X) arrayfun( @(i) repmat(X(i),[1 len_ipa(i)]), 1:numel(len_ipa), 'UniformOutput',false );
L2_ipa = @(X) [X{:}];
L_ipa = @(X) L2_ipa( L1_ipa(X) );
L1_rnd = @(X) arrayfun( @(i) repmat(X(i),[1 len_rnd(i)]), 1:numel(len_rnd), 'UniformOutput',false );
L2_rnd = @(X) [X{:}];
L_rnd = @(X) L2_rnd( L1_rnd(X) );

nVV_l_ipa = L_ipa( nVV_ipa );
nVV_l_rnd = L_rnd( nVV_rnd );
dim_l_ipa = L_ipa( dim_ipa );
dim_l_rnd = L_rnd( dim_rnd );

n_cb_l_ipa = [cb_ipa.bg(idx_ipa).normval];
n_cb_l_rnd = [cb_rnd.bg(idx_rnd).normval];
n_ce_l_ipa = [ce_ipa.ce25(idx_ipa).normval];
n_ce_l_rnd = [ce_rnd.ce25(idx_rnd).normval];
n_ipa = min( n_ce_l_ipa(2,:), n_cb_l_ipa(2,:) );
n_rnd = min( n_ce_l_rnd(2,:), n_cb_l_rnd(2,:) );

acc_cb_l_ipa = n_ipa./n_cb_l_ipa(2,:);
acc_cb_l_rnd = n_rnd./n_cb_l_rnd(2,:);

%% plot data 1
import exportfig.*


for i = 1:2
    FIG();
    clf;
    switch i
        case 1; plotm( [1-acc_cb_l_ipa;dim_l_ipa], '.', 'color',nVV_l_ipa, 'ms',4 );
        case 2; plotm( [1-acc_cb_l_rnd;dim_l_rnd], '.', 'color',nVV_l_rnd, 'ms',4 ); end;
    colorbar
    colormap hsv;
    LABEL( 'Accuracy', '$d$',  '', '$\#V$' );
    AXIS( [.5^26 .5^1 0 30], [0 1500] )
    TICKS( [.5^25 .5^21 .5^17 .5^13 .5^9 .5^5 .5^1],nan, nan, [300 600 900 1200] )
    TICKLABELS( {'0.99999997' '' '.999992' '' '.9998' '0.969' '.5'} );
    set ( gca, 'XScale', 'log' );
    set ( gca, 'xdir', 'reverse' );
    SZE( 2, 2 );
    POST();
    switch i
        case 1; SAVE( '.', 'accuracy_cb_ipa' );
        case 2; SAVE( '.', 'accuracy_cb_rnd' ); end;
end;

%% plot data 2
import exportfig.*


for i = 1:2
    FIG();
    clf;
    switch i
        case 1; plotm( [1:numel(acc_cb_l_ipa)-1;sort(1-acc_cb_l_ipa)], '.', 'color',nVV_l_ipa, 'ms',4 );
        case 2; plotm( [1:numel(acc_cb_l_rnd)-1;sort(1-acc_cb_l_rnd)], '.', 'color',nVV_l_rnd, 'ms',4 ); end;
    colorbar
    colormap hsv;
    LABEL( 'cdf', 'Accuracy', '', '$\#V$' );
    AXIS( [nan nan .5^17 .5^1], [0 1500] )
    TICKS( [nan], [ .5^17 .5^13 .5^9 .5^5 1-1/sqrt(2) .5^1], nan, [300 600 900 1200] )
    TICKLABELS( {}, {'.999992' '.9998' '.998' '.969' '.7071' '.5'} );
    set ( gca, 'YScale', 'log' );
    set ( gca, 'ydir', 'reverse' );
    SZE( 2, 2 );
    POST();
    switch i
        case 1; SAVE( '.', 'accuracy_cb_ipa_sorted' );
        case 2; SAVE( '.', 'accuracy_cb_rnd_sorted' ); end;
end;

%% plot data 3
import exportfig.*


for i = 1:2
    FIG();
    clf;
    switch i
        case 1; data = acc_cb_l_ipa;
        case 2; data = acc_cb_l_rnd; end;
    histogram( log(convm(1-data,[1])),150, 'FaceColor','k', 'EdgeAlpha',0, 'Normalization','pdf' );
    LABEL( 'Accuracy', 'Probability' );
    AXIS( [log(.5^17) log(.5^0) 0 .9] );
    TICKS( [log(.5^17) log(.5^13) log(.5^9) log(.5^5) log(.5^1)], [.2 .4 .6 .8] )
    TICKLABELS( {'.999992' '.9998' '.998' '.969' '.5'} );
    set ( gca, 'xdir', 'reverse' );
    SZE( 2, 2 );
    POST();
    switch i
        case 1; SAVE( '.', 'accuracy_cb_ipa_pdf', 'png' );
        case 2; SAVE( '.', 'accuracy_cb_rnd_pdf', 'png' ); end;
end;





