%% main script
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% we want to compare the results of method3 (COMPLEXFUNCT_D) and method1 (COMPLEXFUNCT_B) 
% on vertices and polytopes occuring in case (C) in the invariant polytope algorithm
%

%#ok<*UNRCH>
%#ok<*SAGROW>

return;

%% generate vertices and polytopes and dump them to base-ws
clear
dim = 2;
j = 0;
lastidx = 0;
%%
load methodcomparison_ipa;
runflag = true;
while( runflag );    
    j = j + 1;
    fprintf( 'j = %i\n', j );
    if( ~mod(j,20)==0 );
        dim = dim + randi(3); end;
    T_ = tgallery( 'complex', dim, 2 );

    tjsr( T_, 'maxiteration',45, 'admissiblealgorithm',[20 21 22 23 24 25 26], 'algorithm','cb', 'epssym',nan, 'solver','g', 'dumpvertex','pt_VV' );
    for k = lastidx+1:numel(pt_VV);
        [ g(k).normval, ~, g(k).iter, g(k).time ] = polytopenorm( pt_VV(k).pts, pt_VV(k).VV, 'c', 'bound',[0 1], 'g' ); fprintf('\n');
        [ m(k).normval, ~, m(k).iter, m(k).time ] = polytopenorm( pt_VV(k).pts, pt_VV(k).VV, 'c', 'bound',[0 1], 'm' ); fprintf('\n');
        [ bm(k).normval, ~, bm(k).iter, bm(k).time ] = polytopenorm( pt_VV(k).pts, pt_VV(k).VV, 'cb', 'bound',[0 1], 'm' ); fprintf('\n');
        [ dm(k).normval, ~, dm(k).iter, dm(k).time ] = polytopenorm( pt_VV(k).pts, pt_VV(k).VV, 'cd', 'bound',[0 1], 'm' ); fprintf('\n');
        [ eg(k).normval, ~, eg(k).iter, eg(k).time ] = polytopenorm( pt_VV(k).pts, pt_VV(k).VV, 'ce', 'bound',[0 1], 'g' ); fprintf('\n');
        fprintf( '\n' );
    end
    
    lastidx = numel(pt_VV);
    save methodcomparison_ipa;
    fprintf( '\n==================================\n' );
end

%% compute missing norms using various methods
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
load methodcomparison_ipa;
for i = 1:numel( pt_VV );
    %[pt_VV(i).normd,pt_VV(i).ivd,pt_VV(i).iterationd,pt_VV(i).timed] = polytopenorm( pt_VV(i).pts, pt_VV(i).VV, 'cd', 'bound',[0 1], 'm' );
end
save methodcomparison_ipa;

%% load data
%%%%%%%%%%%%%%%
clear
load methodcomparison_ipa;
clear ans dim j runflag T_ lastidx k

IDX = ~arrayfun( @(n) isempty(g(n).iter), 1:numel(pt_VV) );
g = g(IDX);
m = m(IDX);
bm = bm(IDX);
dm = dm(IDX);
eg = eg(IDX);
pt_VV = pt_VV(IDX);

len = arrayfun( @(i) size(pt_VV(i).pts,2), 1:numel(pt_VV) );
L1 = @(X) arrayfun( @(i) repmat(X(i),[1 len(i)]), 1:numel(len), 'UniformOutput',false );
L2 = @(X) [X{:}];
L = @(X) L2(L1(X));

NVV = arrayfun( @(i) size(pt_VV(i).VV,2), 1:numel(pt_VV) );
NVV_L = L( NVV );

DIM = arrayfun( @(i) size(pt_VV(i).pts,1), 1:numel(pt_VV) );
DIM_L = L( DIM );

NORMG_L = [g.normval];
NORMM_L = [m.normval];
NORMBM_L = [bm.normval];
NORMDM_L = [dm.normval];
NORMEG_L = [eg.normval];
NORM_L = [ mean( [NORMG_L(1,:);NORMM_L(1,:);NORMBM_L(1,:);NORMDM_L(1,:);NORMEG_L(1,:);] );
           min(  [NORMG_L(2,:);NORMM_L(2,:);NORMBM_L(2,:);NORMDM_L(2,:);NORMEG_L(2,:);] );
           max(  [NORMG_L(3,:);NORMM_L(3,:);NORMBM_L(3,:);NORMDM_L(3,:);NORMEG_L(3,:);] );
         ];

ACCG_L = NORMG_L(2,:)./NORM_L(2,:);
ACCM_L = NORMM_L(2,:)./NORM_L(2,:);
ACCBM_L = NORMBM_L(2,:)./NORM_L(2,:);
ACCDM_L = NORMDM_L(2,:)./NORM_L(2,:);
ACCEG_L = NORMEG_L(2,:)./NORM_L(2,:);

TIMEG = [g.time]; TIMEG_L = L( TIMEG );
TIMEM = [m.time]; TIMEM_L = L( TIMEM );
TIMEBM = [bm.time]; TIMEBM_L = L( TIMEBM );
TIMEDM = [dm.time]; TIMEDM_L = L( TIMEDM );
TIMEEG = [eg.time]; TIMEEG_L = L( TIMEEG );

%%
import exportfig.*;
for i = 1:3;
    switch i;
        case 1; y = TIMEBM;
        case 2; y = TIMEDM;
        case 3; y = TIMEEG; end;
    FIG( i );
    plotm( [DIM;y], '.', 'color',log10(NVV), 'violin',[-.1,.1], 'ms',4, 'semilogy' );
    colorbar
    AXIS( [2 26 0.05 300], [.3 2.8] );
    TICKS( [4 8 12 16 20 24], [ .2 2 20 200 ], nan, [log10(round((10^0.5))) log10(round((10^1.5))) log10(round((10^2.5)))] );
    TICKLABELS( [], [], [], {round((10^0.5)) round((10^1.5)) round((10^2.5))} )
    LABEL( '$dim$','$t\ [s]$', '', '$\#V$' );
    
    switch i;
        case 1; ttl = 'Complex Polytope Method (Method B)'
        case 2; ttl = 'Corner Cutting Method (Method D)';
        case 3; ttl = 'Linear Programming Method (Method E)'; end;
    TITLE( ttl );
    %SZE(2,2);
    colormap hsv;
    
    switch i;
        case 1; svn = 'comp_ipa_dim_time_bm';
        case 2; svn = 'comp_ipa_dim_time_dm';
        case 3; svn = 'comp_ipa_dim_time_eg'; end;
        
    %SAVE( '.', svn );
end;


%%






